==> jc-1.4.0.tar.gz: soot/jimple/parser/node/ALocalName.h <==
// public final class soot.jimple.parser.node.ALocalName

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 1cb55c1727dbf651 soot_jimple_parser_node_ALocalName
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class f11c505e3f138fa0 soot_jimple_parser_node_PLocalName

// header file dependencies
// @dep_header soot_jimple_parser_node_PLocalName

#include "soot/jimple/parser/node/PLocalName.h"

#ifndef _JC_soot_jimple_parser_node_ALocalName_H_
#define _JC_soot_jimple_parser_node_ALocalName_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_PName$object;
struct _jc_soot_jimple_parser_node_Switch$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_ALocalName$sub_refs	_jc_soot_jimple_parser_node_ALocalName$sub_refs;
typedef struct _jc_soot_jimple_parser_node_ALocalName$sub_nonrefs	_jc_soot_jimple_parser_node_ALocalName$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_ALocalName$refs	_jc_soot_jimple_parser_node_ALocalName$refs;
typedef struct _jc_soot_jimple_parser_node_ALocalName$nonrefs	_jc_soot_jimple_parser_node_ALocalName$nonrefs;
typedef struct _jc_soot_jimple_parser_node_ALocalName$object	_jc_soot_jimple_parser_node_ALocalName$object;

typedef const struct _jc_soot_jimple_parser_node_ALocalName$vmethods	_jc_soot_jimple_parser_node_ALocalName$vmethods;
typedef const struct _jc_soot_jimple_parser_node_ALocalName$vtable	_jc_soot_jimple_parser_node_ALocalName$vtable;
typedef const struct _jc_soot_jimple_parser_node_ALocalName$vtype	_jc_soot_jimple_parser_node_ALocalName$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_ALocalName$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalName$object *);
extern void _jc_soot_jimple_parser_node_ALocalName$method$_init$dadd6f33d6c98eed(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalName$object *, struct _jc_soot_jimple_parser_node_PName$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_node_ALocalName$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalName$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_ALocalName$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalName$object *);
extern struct _jc_soot_jimple_parser_node_PName$object *_jc_soot_jimple_parser_node_ALocalName$method$getName$30a0ee8779f774c9(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalName$object *);
extern void _jc_soot_jimple_parser_node_ALocalName$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalName$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_ALocalName$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalName$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_ALocalName$method$setName$34bb5e147ac8a9fb(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalName$object *, struct _jc_soot_jimple_parser_node_PName$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_ALocalName$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalName$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_ALocalName$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_ALocalName$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_ALocalName$method_info$getName$30a0ee8779f774c9;
extern _jc_method _jc_soot_jimple_parser_node_ALocalName$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_ALocalName$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_ALocalName$method_info$setName$34bb5e147ac8a9fb;
extern _jc_method _jc_soot_jimple_parser_node_ALocalName$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_ALocalName$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalName$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalName$object *);
	struct _jc_soot_jimple_parser_node_PName$object	*(*getName$30a0ee8779f774c9)(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalName$object *);
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalName$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalName$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*setName$34bb5e147ac8a9fb)(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalName$object *, struct _jc_soot_jimple_parser_node_PName$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalName$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_ALocalName$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PLocalName$vmethods	soot_jimple_parser_node_PLocalName;
	_jc_soot_jimple_parser_node_ALocalName$vmethods	soot_jimple_parser_node_ALocalName;
};

// Vtype
struct _jc_soot_jimple_parser_node_ALocalName$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_ALocalName$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ALocalName$sub_refs {
	struct _jc_soot_jimple_parser_node_PName$object	*__5fname__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_ALocalName$refs {
    _jc_soot_jimple_parser_node_ALocalName$sub_refs	soot_jimple_parser_node_ALocalName;
    _jc_soot_jimple_parser_node_PLocalName$sub_refs	soot_jimple_parser_node_PLocalName;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ALocalName$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_ALocalName$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PLocalName$sub_nonrefs	soot_jimple_parser_node_PLocalName;
    _jc_soot_jimple_parser_node_ALocalName$sub_nonrefs	soot_jimple_parser_node_ALocalName;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_ALocalName$object {
	_jc_soot_jimple_parser_node_ALocalName$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_ALocalName$vtype	*vtype;
	_jc_soot_jimple_parser_node_ALocalName$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_ALocalName$vtype _jc_soot_jimple_parser_node_ALocalName$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_ALocalName, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_ALocalName$class_object;

#endif	/* _JC_soot_jimple_parser_node_ALocalName_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/ALocalName.h <==
// public final class soot.jimple.parser.node.ALocalName

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 1cb55c1727dbf651 soot_jimple_parser_node_ALocalName
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class f11c505e3f138fa0 soot_jimple_parser_node_PLocalName

// header file dependencies
// @dep_header soot_jimple_parser_node_PLocalName

#include "soot/jimple/parser/node/PLocalName.h"

#ifndef _JC_soot_jimple_parser_node_ALocalName_H_
#define _JC_soot_jimple_parser_node_ALocalName_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_PName$object;
struct _jc_soot_jimple_parser_node_Switch$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_ALocalName$sub_refs	_jc_soot_jimple_parser_node_ALocalName$sub_refs;
typedef struct _jc_soot_jimple_parser_node_ALocalName$sub_nonrefs	_jc_soot_jimple_parser_node_ALocalName$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_ALocalName$refs	_jc_soot_jimple_parser_node_ALocalName$refs;
typedef struct _jc_soot_jimple_parser_node_ALocalName$nonrefs	_jc_soot_jimple_parser_node_ALocalName$nonrefs;
typedef struct _jc_soot_jimple_parser_node_ALocalName$object	_jc_soot_jimple_parser_node_ALocalName$object;

typedef const struct _jc_soot_jimple_parser_node_ALocalName$vmethods	_jc_soot_jimple_parser_node_ALocalName$vmethods;
typedef const struct _jc_soot_jimple_parser_node_ALocalName$vtable	_jc_soot_jimple_parser_node_ALocalName$vtable;
typedef const struct _jc_soot_jimple_parser_node_ALocalName$vtype	_jc_soot_jimple_parser_node_ALocalName$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_ALocalName$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalName$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ALocalName$method$_init$dadd6f33d6c98eed(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalName$object *, struct _jc_soot_jimple_parser_node_PName$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_ALocalName$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalName$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_ALocalName$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalName$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_parser_node_PName$object *_jc_soot_jimple_parser_node_ALocalName$method$getName$30a0ee8779f774c9(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalName$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ALocalName$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalName$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ALocalName$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalName$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ALocalName$method$setName$34bb5e147ac8a9fb(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalName$object *, struct _jc_soot_jimple_parser_node_PName$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_ALocalName$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalName$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_ALocalName$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_ALocalName$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_ALocalName$method_info$getName$30a0ee8779f774c9;
extern _jc_method _jc_soot_jimple_parser_node_ALocalName$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_ALocalName$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_ALocalName$method_info$setName$34bb5e147ac8a9fb;
extern _jc_method _jc_soot_jimple_parser_node_ALocalName$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_ALocalName$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalName$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalName$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_parser_node_PName$object	*(*getName$30a0ee8779f774c9)(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalName$object *) _JC_JCNI_ATTR;
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalName$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalName$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*setName$34bb5e147ac8a9fb)(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalName$object *, struct _jc_soot_jimple_parser_node_PName$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_ALocalName$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_ALocalName$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PLocalName$vmethods	soot_jimple_parser_node_PLocalName;
	_jc_soot_jimple_parser_node_ALocalName$vmethods	soot_jimple_parser_node_ALocalName;
};

// Vtype
struct _jc_soot_jimple_parser_node_ALocalName$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_ALocalName$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ALocalName$sub_refs {
	struct _jc_soot_jimple_parser_node_PName$object	*__5fname__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_ALocalName$refs {
    _jc_soot_jimple_parser_node_ALocalName$sub_refs	soot_jimple_parser_node_ALocalName;
    _jc_soot_jimple_parser_node_PLocalName$sub_refs	soot_jimple_parser_node_PLocalName;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ALocalName$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_ALocalName$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PLocalName$sub_nonrefs	soot_jimple_parser_node_PLocalName;
    _jc_soot_jimple_parser_node_ALocalName$sub_nonrefs	soot_jimple_parser_node_ALocalName;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_ALocalName$object {
	_jc_soot_jimple_parser_node_ALocalName$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_ALocalName$vtype	*vtype;
	_jc_soot_jimple_parser_node_ALocalName$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_ALocalName$vtype _jc_soot_jimple_parser_node_ALocalName$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_ALocalName, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_ALocalName$class_object;

#endif	/* _JC_soot_jimple_parser_node_ALocalName_H_ */
